<?php

namespace Fa\Portal\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Fa\Portal\Interfaces\EstateRepositoryInterface;
use Fa\Portal\Repositories\Presenter\EstateItemTransformer;

/**
 * Pubic API controller class.
 */
class EstatePublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Fa\Estate\Interfaces\EstateRepositoryInterface $estate
     *
     * @return type
     */
    public function __construct(EstateRepositoryInterface $estate)
    {
        $this->repository = $estate;
        parent::__construct();
    }

    /**
     * Show estate's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $estates = $this->repository
            ->setPresenter('\\Fa\\Portal\\Repositories\\Presenter\\EstateListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $estates['code'] = 2000;
        return response()->json($estates)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show estate.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $estate = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($estate)) {
            $estate         = $this->itemPresenter($module, new EstateItemTransformer);
            $estate['code'] = 2001;
            return response()->json($estate)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
