<?php

namespace Fa\Portal\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Fa\Portal\Models\Estate;

class EstatePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the estate.
     *
     * @param User $user
     * @param Estate $estate
     *
     * @return bool
     */
    public function view(User $user, Estate $estate)
    {
        if ($user->canDo('portal.estate.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $estate->user_id;
    }

    /**
     * Determine if the given user can create a estate.
     *
     * @param User $user
     * @param Estate $estate
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('portal.estate.create');
    }

    /**
     * Determine if the given user can update the given estate.
     *
     * @param User $user
     * @param Estate $estate
     *
     * @return bool
     */
    public function update(User $user, Estate $estate)
    {
        if ($user->canDo('portal.estate.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $estate->user_id;
    }

    /**
     * Determine if the given user can delete the given estate.
     *
     * @param User $user
     * @param Estate $estate
     *
     * @return bool
     */
    public function destroy(User $user, Estate $estate)
    {
        if ($user->canDo('portal.estate.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $estate->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
